"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const strictFiles_1 = require("./strictFiles");
const init = () => {
    function create(info) {
        const proxy = utils_1.setupProxy(info);
        utils_1.log(info, 'Plugin initialized');
        proxy.getSemanticDiagnostics = function (fileName) {
            const strictFile = new strictFiles_1.StrictFileChecker(info).isFileStrict(fileName);
            if (strictFile) {
                return getDiagnosticsWithStrictMode(info, fileName);
            }
            return info.languageService.getSemanticDiagnostics(fileName);
        };
        return proxy;
    }
    function getDiagnosticsWithStrictMode(info, fileName) {
        utils_1.turnOnStrictMode(info, info.project.getCompilerOptions());
        const diagnostics = info.languageService.getSemanticDiagnostics(fileName);
        utils_1.turnOffStrictMode(info, info.project.getCompilerOptions());
        return diagnostics;
    }
    return { create };
};
module.exports = init;
